<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>Souborové nástroje</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>Zobrazit souborové nástroje</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location line="+91"/>
        <location line="+69"/>
        <source>Format:</source>
        <translation>Formát:</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Overwrite File?</source>
        <translation>Přepsat soubor?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Soubor &apos;%1&apos; již existuje. Přeješ si ho přepsat?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All Files</source>
        <translation>Všechny soubory</translation>
    </message>
</context>
</TS>
